@@ -1,6 +1,7 @@
 use ltv::*;
 
 #[derive(Debug, Ltv, Default, PartialEq, Eq)]
+#[object_id = 10]
 struct ExampleStruct {
     #[ltv_field(1)]
     field1: u8,
@@ -8,7 +9,7 @@ struct ExampleStruct {
 
 fn main() {
     let original_ltv = ExampleStruct { field1: 0x69 };
-    let ltv_bytes = original_ltv.to_ltv_object(0x44);
+    let ltv_bytes = original_ltv.to_ltv_object();
 
     println!("{:?}", &ltv_bytes);
     let new_ltv = ExampleStruct::from_ltv_object(&ltv_bytes).unwrap();
