@@ -1,14 +1,16 @@
 use std::error::Error;
 
-
 #[derive(Debug)]
 pub enum LTVError {
-    WrongSize{field_id: usize, expected: usize, recieved: usize},
+    WrongSize {
+        field_id: usize,
+        expected: usize,
+        recieved: usize,
+    },
     NotFound(usize),
 }
 
-impl Error for LTVError {
-}
+impl Error for LTVError {}
 
 impl std::fmt::Display for LTVError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
@@ -16,4 +18,4 @@ impl std::fmt::Display for LTVError {
     }
 }
 
-pub type LTVResult<T> = std::result::Result<T, LTVError>;
\ No newline at end of file
+pub type LTVResult<T> = std::result::Result<T, LTVError>;
