@@ -1,4 +1,4 @@
-use std::{convert::TryInto, mem, u128};
+use std::{convert::TryInto, u128};
 
 use crate::{
     error::{LTVError, LTVResult},
@@ -10,20 +10,20 @@ pub trait LTVObjectGroup<'a, const ED: ByteOrder>: Sized {
     fn from_ltv(data: &'a [u8]) -> Option<Self>;
 }
 
-pub trait LTVItem<const ED: ByteOrder>: Sized {
+pub trait LTVItem<const ED: ByteOrder> {
     type Item: LTVItem<ED>;
     fn from_ltv(field_type: usize, data: &[u8]) -> LTVResult<Self::Item>;
     fn to_ltv(&self) -> Vec<u8>;
 }
 
-pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize>: LTVItem<ED> {
+pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize, const OBJECT_ID: u8>: LTVItem<ED> {
     fn from_ltv_object(data: &'a [u8]) -> LTVResult<Self::Item> {
         use crate::reader::LTVReader;
         let (_, obj_id, data) = LTVReader::<'a, ED, LENGTH_BYTE>::parse_ltv(data)?;
         Ok(Self::from_ltv(obj_id, data)?)
     }
 
-    fn to_ltv_object(&self, object_id: u8) -> Vec<u8> {
+    fn to_ltv_object(&self) -> Vec<u8> {
         let mut data = self.to_ltv();
         let mut out_ltv = Vec::with_capacity(LENGTH_BYTE + 1);
 
@@ -41,7 +41,7 @@ pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize>: LTVItem<
         };
 
         //ED::write_u16(&mut out_ltv, (data.len() + 1) as u16),
-        out_ltv.push(object_id);
+        out_ltv.push(OBJECT_ID);
         out_ltv.append(&mut data);
 
         out_ltv
@@ -51,8 +51,11 @@ pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize>: LTVItem<
 impl<'a, T: LTVItem<ED>, const ED: ByteOrder> LTVItem<ED> for Option<T> {
     type Item = Option<T::Item>;
     fn from_ltv(field_id: usize, data: &'_ [u8]) -> LTVResult<Self::Item> {
-        let o = T::from_ltv(field_id, data);
-        Ok(None)
+        match T::from_ltv(field_id, data) {
+            Ok(e) => Ok(Some(e)),
+            Err(LTVError::NotFound(_)) => Ok(None),
+            Err(e) => return Err(e),
+        }
     }
 
     fn to_ltv(&self) -> Vec<u8> {
@@ -87,7 +90,7 @@ macro_rules! impl_numeric_ltvitem {
 
             match numeric_value {
                 Ok(b) => Ok(b),
-                Err(e) => Err(LTVError::WrongSize {
+                Err(_) => Err(LTVError::WrongSize {
                     field_id: field_id,
                     expected: ($i::BITS/8) as usize,
                     recieved: data.len(),
